#include "ti86asm.inc"
#include "dqfight.inc"
#include "dqtalk.inc"

.org $D748
;WALKAROUND2 = $d7f8
savesize = 131
	nop
	jp ProgStart
	.dw 0
	.dw ShellTitle

ShellTitle:
	.db "Dragon Quest 86",0

ProgStart:
	call waitkey
	call _runindicoff
	call LoadGreyscale
	call ClearScreen
	ld bc, $000f
	ld de, $0106
	call makewindow
	ld hl, ShellTitle
	ld de, $0b20
	call drawstring
	ld hl, titlescreen1
	ld de, $1204
	call drawstring
	ld hl, titlescreen2
	ld de, $2305
	call drawstring
	ld hl, titlescreen3
	ld de, $2a05
	call drawstring
titleloop:
	ld b, 1
	call keyloop
	cp 9
	jr z, loadgame
	cp 0
	jr z, titleloop
	call ClearScreen
	call WalkAround
finishgame:
	call CloseGrey
	jp ClearScreen

loadgame:
	ld hl, dwsave
	call loadstring
	ld hl, $8100
	ld de, hp
	ld bc, savesize
	ldir
	call LoadMap
	ld hl, herospritedown1
	ld (dirword), hl
	call LoadTileMap
	call pause
	call startgame
	jr finishgame
	
WalkAround:
	call waitkey
	ld hl,$1de0
	ld (curmap), hl
	call LoadMap
	ld hl, herospriteup1
	ld (dirword), hl
	ld hl, 4141
	ld (playerpos), hl
	call LoadTileMap
	ld hl, TBeginning
	call gsearch4

startgame:
	ld hl, (playerpos)

WalkAround2:
	ld (playerpos), hl
	call LoadTileMap
	ld b, 45													;The BIG nothing loop
	ld a, (relic1)
	cp 25
	jr z, speedshoes
	ld a, (relic2)
	cp 25
	jr nz, nospeedshoes
speedshoes:
	ld b, 25
nospeedshoes:
	call keyloop
	ld a, (walkvar)
	ld b, a
	ld a, 1
	sub b
	ld (walkvar), a
	ld a, (sameblock)
	cp 30
	jp z, falloutofdungeon							
	ld hl, (playerpos)
	ld a, (keyvar)
	cp 1
	jp z, gomapdown
	cp 2
	jp z, gomapleft
	cp 3
	jp z, gomapright
	cp 4
	jp z, gomapup
	cp 6
	call z, AIselect
	cp 7
	call z, contrastup
	ld a, (keyvar)
	cp 8
	call z, contrastdown
	cp 10	
	call z, showmenu
	ld a, (keyvar)
	ld hl, (playerpos)
	cp 5
	jp nz, WalkAround2
	ret

falloutofdungeon:
	ld b, 3
foodloop:
	push bc
	dec b
	ld a, b
	ld (radiance), a
	call LoadTileMap
	ld b, 10
	call keyloop
	pop bc
	djnz foodloop
	ld hl, 0
	ld (curmap), hl
	call loadmap
	ld hl, (worldpos)
	ld (playerpos), hl
	jp WalkAround2
;*************************************************************************
;* Moving Directions                                                     *
;*************************************************************************

gomapup:
	ld (lookdir), a
	ld a, (upblock)
	ld de, herospriteup1
	call checkmove
	jp z, WalkAround2
	ld de, (curmapwidth)
	sub a
	sbc hl, de
	jp justmovedaround

gomapdown:
	ld (lookdir), a
	ld a, (downblock)
	ld de, herospritedown1
	call checkmove
	jp z, WalkAround2
	ld de, (curmapwidth)
	add hl, de
	jp justmovedaround

gomapright:
	ld (lookdir), a
	ld a, (rightblock)
	ld de, herospriteright1
	call checkmove
	jp z, WalkAround2
	inc hl
	jp justmovedaround
	
gomapleft:
	ld (lookdir), a
	ld a, (leftblock)
	ld de, herospriteleft1
	call checkmove
	jp z, WalkAround2
	dec hl
	jr justmovedaround

checkmove:
	ld (dirword), de
	cp 100
	jr z, opendoor
	cp 101
	jr z, opendoor
	ld c, 61
	push af
	ld a, (relic1)
	cp 20
	jr z, hovershoes
	ld a, (relic2)
	cp 20
	jr nz, nohovershoes
hovershoes:
	inc c
nohovershoes:
	pop af
	cp c
	jr nc, blockedtile
opendoor:
	inc a
	ret
blockedtile:
	xor a
	ret


justmovedaround:
	ld (playerpos), hl
	ld a, (hazelnuton)
	cp 1
	call z, usethathazel
	ld a, r
	cp 10
	call c, loadfight
	ld a, (curmapwidth)
	cp 64
	jr c, skiprad
	ld a, 3
	ld (radiance), a
skiprad:
	call checktransport
	ld hl, (playerpos)
	jp WalkAround2

usethathazel:
	xor a
	ld (hazelnuton), a
loadfight:
	ld a, (monster1)
	cp 0
	ret z
rloadfight:
	ld hl, dwfight
	call loadstring
	ld a, 1
	ld (fighton), a
	call fight
	xor a
	ld (fighton), a
	jp loadmap
;*************************************************************************
;* Transport Checking Stuff                                              *
;*************************************************************************

checktransport:
	ld de, (playerpos)
	ld (cpword), de
	call cplocation
	ld a, b
	cp 0
	ret z												;if b=0 then it found nothing, else hl=location of starting byte (byte #4)
	ld a, (hl)
	cp 255
	ret z
	push hl
	ld a, (curmapwidth)
	cp 64
	call nc, savepos
	pop hl												;load new map positions
	ld e, (hl)
	inc hl
	ld d, (hl)
	ld (curmap), de
	inc hl
	ld e, (hl)
	inc hl
	ld d, (hl)
	ld (playerpos), de
	call LoadMap									;draw new map info
	ld de, herospritedown1
	ld (dirword), de
	call LoadTileMap
	ld b, 1
	ret
savepos:
	ld hl, (playerpos)
	ld (worldpos), hl
	ret

bigscreencloop:
	push bc
	ld c, (hl)
	dec hl
	ld b, (hl)
	dec hl
	ex de, hl
	ld (hl), c
	dec hl
	ld (hl), b
	dec hl
	ex de, hl
	pop bc
	djnz bigscreencloop
	ret

;*************************************************************************
;* Map Loading                                                           *
;*************************************************************************

#include dqmenu.asm

LoadMap:
	ld de, (curmap)
	ld a, d
	ld hl, dwmaps
	cp $60
	call nc, loaddqmaps3
	cp $30
	call nc, loaddqmaps2
	ld (tempmap), de
	call loadstring
	ld de, (tempmap)
	add hl, de
	ld a, (hl)
	ld d, 0
	ld e, a
	ld (curmapwidth), de
	inc hl
	ld a, (hl)
	ld (monster1), a
	inc hl
	ld a, (hl)
	ld (monster2), a
	inc hl
	ld e, (hl)
	inc hl
	ld d, (hl)
	inc hl
	ld (mapsize), de
	ld (mappos), hl
	ret
loaddqmaps2:
	ld hl, dwmaps2
	sub $30
	ld d, a
	ret
loaddqmaps3:
	ld hl, dqmaps3
	sub $60
	ld d, a
	ret
tempmap:
	.dw 0

#include variable.asm											;variables (strings, etc.)
#include dqmapsprites.asm									;gfx
#include dqcharsprites.asm									;gfx
#include subroutes.asm										;subroutines
#include greyscale.asm										;greyscale routines
#include gselect.asm											;general selection thing
#include LTM.asm													;Load Tile Map


.end
